@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getDetail(vmanage, clusterName):
     """
     Get details of all existing Clusters
@@ -14,8 +11,8 @@ def getDetail(vmanage, clusterName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster?clusterName={clusterName}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/cluster?clusterName={clusterName}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def update(vmanage, clusterconfig):
@@ -31,8 +28,8 @@ def update(vmanage, clusterconfig):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, clusterconfig)
+    endpoint = f"dataservice/colocation/cluster"
+    response = vmanage.apiCall("PUT", endpoint, clusterconfig)
     return response
 
 def create(vmanage, clusterconfig):
@@ -48,8 +45,8 @@ def create(vmanage, clusterconfig):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, clusterconfig)
+    endpoint = f"dataservice/colocation/cluster"
+    response = vmanage.apiCall("POST", endpoint, clusterconfig)
     return response
 
 def acitvate(vmanage, clusterName):
@@ -65,8 +62,8 @@ def acitvate(vmanage, clusterName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/activate?clusterName={clusterName}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/colocation/cluster/activate?clusterName={clusterName}"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def dummyccm(vmanage, clusterName):
@@ -82,8 +79,8 @@ def dummyccm(vmanage, clusterName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/activateClusterDummy?clusterName={clusterName}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/cluster/activateClusterDummy?clusterName={clusterName}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def dummycspState(vmanage, clusterName, state):
@@ -100,8 +97,8 @@ def dummycspState(vmanage, clusterName, state):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/activateClusterDummyState?clusterName={clusterName}&state={state}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/cluster/activateClusterDummyState?clusterName={clusterName}&state={state}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def updateCspToCluster(vmanage, cspconfig):
@@ -117,8 +114,8 @@ def updateCspToCluster(vmanage, cspconfig):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/attached/csp"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, cspconfig)
+    endpoint = f"dataservice/colocation/cluster/attached/csp"
+    response = vmanage.apiCall("PUT", endpoint, cspconfig)
     return response
 
 def preview(vmanage, serialNumber):
@@ -134,8 +131,8 @@ def preview(vmanage, serialNumber):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/config?serialNumber={serialNumber}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/cluster/config?serialNumber={serialNumber}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def deAcitvate(vmanage, clusterId):
@@ -151,8 +148,8 @@ def deAcitvate(vmanage, clusterId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/deactivate?clusterId={clusterId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/colocation/cluster/deactivate?clusterId={clusterId}"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def getDetailById(vmanage, clusterId):
@@ -168,8 +165,8 @@ def getDetailById(vmanage, clusterId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/id?clusterId={clusterId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/cluster/id?clusterId={clusterId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def rmaCloudDockCsp(vmanage, bodyParameter, clusterName):
@@ -186,8 +183,8 @@ def rmaCloudDockCsp(vmanage, bodyParameter, clusterName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/rma?clusterName={clusterName}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
+    endpoint = f"dataservice/colocation/cluster/rma?clusterName={clusterName}"
+    response = vmanage.apiCall("POST", endpoint, bodyParameter)
     return response
 
 def deleteByName(vmanage, clustername):
@@ -203,6 +200,6 @@ def deleteByName(vmanage, clustername):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/cluster/{clustername}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/colocation/cluster/{clustername}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
