@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getFileContents(vmanage, uuid):
     """
     Get bootstrap file contents
@@ -14,8 +11,8 @@ def getFileContents(vmanage, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/package/custom/file/{uuid}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/package/custom/file/{uuid}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editConfigFile(vmanage, bootstrapfile, uuid):
@@ -32,8 +29,8 @@ def editConfigFile(vmanage, bootstrapfile, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/package/custom/file/{uuid}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, bootstrapfile)
+    endpoint = f"dataservice/device/action/software/package/custom/file/{uuid}"
+    response = vmanage.apiCall("PUT", endpoint, bootstrapfile)
     return response
 
 def uploadImageFile(vmanage, type):
@@ -49,8 +46,8 @@ def uploadImageFile(vmanage, type):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/package/custom/uploads/{type}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/device/action/software/package/custom/uploads/{type}"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def createVnfPackage(vmanage, custompackage):
@@ -66,6 +63,6 @@ def createVnfPackage(vmanage, custompackage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/package/custom/vnfPackage"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, custompackage)
+    endpoint = f"dataservice/device/action/software/package/custom/vnfPackage"
+    response = vmanage.apiCall("POST", endpoint, custompackage)
     return response
