@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getPolicies(vmanage, nmsId):
     """
     Retrieve MDP policies
@@ -14,8 +11,8 @@ def getPolicies(vmanage, nmsId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/policies/{nmsId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/mdp/policies/{nmsId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def updatePolicyStatus(vmanage, policylist, nmsId):
@@ -32,6 +29,6 @@ def updatePolicyStatus(vmanage, policylist, nmsId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/policies/{nmsId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policylist)
+    endpoint = f"dataservice/mdp/policies/{nmsId}"
+    response = vmanage.apiCall("PUT", endpoint, policylist)
     return response
